@@ -6,6 +6,7 @@
 import doctest
 
 from compat import unittest
+from support import DistlibTestCase
 
 from distlib.version import (NormalizedVersion as NV, NormalizedMatcher as NM,
                              UnsupportedVersionError,
@@ -17,7 +18,7 @@ from distlib.version import (NormalizedVersion as NV, NormalizedMatcher as NM,
                              _normalized_key, _legacy_key, _semantic_key)
 
 
-class VersionTestCase(unittest.TestCase):
+class VersionTestCase(DistlibTestCase):
 
     versions = ((NV('1.0'), '1.0'),
                 (NV('1.1'), '1.1'),
@@ -161,6 +162,9 @@ class VersionTestCase(unittest.TestCase):
         self.assertGreater(NV('1.0'), NV('1.0rc2'))
         self.assertGreater(NV('1.0rc2'), NV('1.0rc1'))
         self.assertGreater(NV('1.0c4'), NV('1.0c1'))
+        self.assertGreater(NV('2014.04'), NV('2013.10'))
+        self.assertGreater(NV('1!1.1'), NV('2014.04'))
+        self.assertGreater(NV('1!2.0'), NV('1!1.1'))
 
     def test_suggest_normalized_version(self):
         suggest = _suggest_normalized_version
@@ -267,8 +271,10 @@ class VersionTestCase(unittest.TestCase):
         # Test that names are parsed the right way
 
         self.assertEqual('Hey', NM('Hey (<1.1)').name)
+        self.assertEqual('9Hey', NM('9Hey (1.1)').name)
         self.assertEqual('Foo-Bar', NM('Foo-Bar (1.1)').name)
-        self.assertEqual('Foo Bar', NM('Foo Bar (1.1)').name)
+        self.assertEqual('Foo_Bar', NM('Foo_Bar (1.1)').name)
+        self.assertEqual('Foo.Bar', NM('Foo.Bar (1.1)').name)
 
     def test_matcher_local(self):
         self.assertTrue(NM('Foo (>=2.5+1.2)').match('2.6.0+1.3'))
@@ -323,7 +329,7 @@ class VersionTestCase(unittest.TestCase):
         for s in final_releases:
             self.assertFalse(NV(s).is_prerelease)
 
-    def test_comparison_pep426(self):
+    def test_comparison_pep440(self):
         versions = (
             '1.0.dev456',
             '1.0a1',
@@ -440,10 +446,10 @@ class VersionTestCase(unittest.TestCase):
             self.assertRaises(ValueError, NM, s)
         for v in ('', '1.*.*'):
             s = 'foo (== %s)' % v
-            self.assertRaises(ValueError, NM, s)
+            self.assertRaises((SyntaxError, ValueError), NM, s)
 
 
-class LegacyVersionTestCase(unittest.TestCase):
+class LegacyVersionTestCase(DistlibTestCase):
     # These tests are the same as distribute's
     def test_equality(self):
         def compare(a, b):
@@ -538,7 +544,7 @@ class LegacyVersionTestCase(unittest.TestCase):
             self.assertFalse(LV(s).is_prerelease, s)
 
 
-class SemanticVersionTestCase(unittest.TestCase):
+class SemanticVersionTestCase(DistlibTestCase):
     def test_basic(self):
         bad = [
             'a', '1', '1.', '1.2' , '1.2.',
@@ -602,7 +608,7 @@ class SemanticVersionTestCase(unittest.TestCase):
             self.assertFalse(SV(s).is_prerelease)
 
 
-class CompatibilityTestCase(unittest.TestCase):
+class CompatibilityTestCase(DistlibTestCase):
     def test_basic(self):
         def are_equal(v1, v2):
             return v1 == v2
